
class FriggSettings(object):
    tasks = {
        'setup': [],
        'tests': [],
        'verbose': [],
        'after_success': [],
        'after_failure': [],
    }
    webhooks = []
    services = []

    def __init__(self, obj):
        if isinstance(obj['tasks'], list):
            obj = self.convert_v1_to_v2(obj)

        self.__dict__.update(obj)

    def validate(self):
        return True

    @staticmethod
    def convert_v1_to_v2(content):
        tasks = {'setup': [], 'tests': [], 'verbose': []}

        if 'setup_tasks' in content:
            tasks['setup'] = content['setup_tasks']

        if 'tasks' in content:
            tasks['tests'] = content['tasks']

        if 'verbose_tasks' in content:
            tasks['verbose'] = content['verbose_tasks']

        content.update({'tasks': tasks})
        return content

    @property
    def has_tests_tasks(self):
        return len(self.tasks['tests']) > 0



from os.path import join

import yaml
from frigg_test_discovery import detect_test_tasks, detect_tox_environments

from .model import FriggSettings


def build_tasks(directory, runner):
    return detect_test_tasks(runner.list_files(directory))


def load_settings_file(path, runner):
    if path is None:
        return {}

    content = yaml.load(runner.read_file(path))

    return content


def get_path_of_settings_file(directory, runner):
    if runner.file_exist(join(directory, '.frigg.yml')):
        return join(directory, '.frigg.yml')
    elif runner.file_exist(join(directory, '.frigg.yaml')):
        return join(directory, '.frigg.yaml')


def build_settings(directory, runner):
    path = get_path_of_settings_file(directory, runner)
    settings = FriggSettings(load_settings_file(path, runner))

    if not settings.has_tests_tasks:
        settings.tasks['tests'] = build_tasks(directory, runner)

    if runner and directory and 'tox' in settings.tasks['tests']:
        settings.tasks['tests'].remove('tox')
        for task in detect_tox_environments(runner, directory):
            settings.tasks['tests'].append('tox -e ' + task)

    if not settings.has_tests_tasks:
        raise RuntimeError('No tasks found')

    return settings



# -*- encoding: utf8 -*-
import re

from setuptools import find_packages, setup


def _read_long_description():
    try:
        import pypandoc
        return pypandoc.convert('README.md', 'rst', format='markdown')
    except Exception:
        return None


version = ''
with open('frigg_settings/__init__.py', 'r') as fd:
    version = re.search(
        r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
        fd.read(),
        re.MULTILINE
    ).group(1)


setup(
    name='frigg-settings',
    version=version,
    description='A module for parsing and discovery of frigg settings file',
    long_description=_read_long_description(),
    packages=find_packages(exclude='tests'),
    author='The frigg team',
    author_email='hi@frigg.io',
    license='MIT',
    url='https://github.com/frigg/frigg-settings',
    py_modules=['frigg_test_discovery'],
    include_package_data=True,
    install_requires=[
        'pyyaml==3.11',
        'frigg-test-discovery>1.0,<2.0',
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
    ]
)
